@@ -20,6 +20,9 @@
 
 #include <glib/gi18n.h>
 #include <stdlib.h>
+#include <libedataserver/libedataserver.h> /* ESourceRegistry */
+#include <libecal/libecal.h>               /* ECalClient      */
+
 
 #include <libbiji/libbiji.h>
 
@@ -293,6 +296,50 @@ on_client_got (GObject *source_object,
   g_list_free (accounts);
 }
 
+
+
+
+
+/*
+ * Currently bjb checks eds accounts
+ * and asks libbiji about them.
+ * This, in case we want a setting
+ * Another way might be to let libbiji live its life
+ */
+void
+on_registry_got (GObject *obj,
+                 GAsyncResult *res,
+                 gpointer user_data)
+{
+  GError *error;
+  ESourceRegistry *registry;
+  GList *list, *l;
+  Bijiben *self = BIJIBEN_APPLICATION (user_data);
+
+  error = NULL;
+  registry = e_source_registry_new_finish (res, &error);
+
+  if (error)
+  {
+    g_warning ("no registry :(, %s", error->message);
+    return;
+  }
+
+  list = e_source_registry_list_sources (registry, E_SOURCE_EXTENSION_MEMO_LIST);
+  for (l=list; l!= NULL; l=l->next)
+  {
+    biji_manager_add_e_source_extension_memo (self->priv->manager, l->data);
+  }
+
+  g_list_free_full (list, g_object_unref);
+}
+
+
+
+
+
+
+
 static void
 bijiben_startup (GApplication *application)
 {
@@ -300,7 +347,7 @@ bijiben_startup (GApplication *application)
   gchar          *storage_path, *default_color;
   GFile          *storage;
   GError         *error;
-  gchar          *path; 
+  gchar          *path;
   GdkRGBA         color = {0,0,0,0};
 
 
@@ -309,11 +356,7 @@ bijiben_startup (GApplication *application)
   error = NULL;
 
 
-  if (gtk_clutter_init (NULL, NULL) != CLUTTER_INIT_SUCCESS)
-  {
-    g_warning ("Unable to initialize Clutter");
-    return;
-  }
+  gtk_init (NULL, NULL);
 
 
   bjb_app_menu_set(application);
@@ -321,7 +364,7 @@ bijiben_startup (GApplication *application)
   storage_path = g_build_filename (g_get_user_data_dir (), "bijiben", NULL);
   storage = g_file_new_for_path (storage_path);
 
-  // Create the bijiben dir to ensure. 
+  // Create the bijiben dir to ensure.
   self->priv->first_run = TRUE;
   g_file_make_directory (storage, NULL, &error);
 
@@ -352,8 +395,9 @@ bijiben_startup (GApplication *application)
   if (error)
     goto out;
 
-  /* Goa */
+  /* Goa, e-d-s */
   goa_client_new  (NULL, on_client_got, self); // cancellable
+  e_source_registry_new (NULL, on_registry_got, self);
 
 
   /* Automatic imports on startup */
