@@ -16,22 +16,26 @@
  */
 
 #include <gtk/gtk.h>
-#include <uuid/uuid.h>
+
 
 #include "libbiji.h"
-#include "biji-local-note.h" // FIXME !!!! biji_provider_note_new ()
 #include "biji-notebook.h"
 #include "biji-error.h"
 
 #include "provider/biji-import-provider.h"
 #include "provider/biji-local-provider.h"
+#include "provider/biji-memo-provider.h"
 #include "provider/biji-own-cloud-provider.h"
 
 
 struct _BijiManagerPrivate
 {
   /* Notes & Collections.
-   * Keep a direct pointer to local provider for convenience. */
+   * Keep a direct pointer to local provider for convenience
+   *
+   * TODO: would be nice to have GHashTable onto providers
+   * rather than one big central db here
+   */
 
   GHashTable *items;
   GHashTable *archives;
@@ -246,6 +250,7 @@ title_is_unique (BijiManager *manager, gchar *title)
   return is_unique;
 }
 
+
 /* If title not unique, add sufffix "n", starting with 2, until ok */
 gchar *
 biji_manager_get_unique_title (BijiManager *manager, const gchar *title)
@@ -289,29 +294,55 @@ biji_manager_notify_changed (BijiManager            *manager,
 
 
 static void
-on_item_deleted_cb (BijiItem *item, BijiManager *manager)
+on_item_deleted_cb (BijiItem *item, BijiManager *self)
 {
   BijiItem        *to_delete;
   const gchar     *path;
-  gboolean         retval;
+  GHashTable      *store;
+  BijiItemsGroup   group;
 
 
   to_delete = NULL;
-  retval = FALSE;
   path = biji_item_get_uuid (item);
-  to_delete = g_hash_table_lookup (manager->priv->archives, path);
+  store = NULL;
 
-  if (to_delete != NULL)
-    retval = TRUE;
+  if ((to_delete = g_hash_table_lookup (self->priv->archives, path)))
+  {
+    store = self->priv->archives;
+    group = BIJI_ARCHIVED_ITEMS;
+  }
+  else if ((to_delete = g_hash_table_lookup (self->priv->items, path)))
+  {
+    store = self->priv->items;
+    group = BIJI_LIVING_ITEMS;
+  }
 
-  if (!retval)
+  if (store == NULL)
     return;
 
-  g_hash_table_remove (manager->priv->archives, path);
-  biji_manager_notify_changed (manager,
-                               BIJI_ARCHIVED_ITEMS,
-                               BIJI_MANAGER_ITEM_DELETED,
-                               item);
+
+  g_hash_table_remove (store, path);
+  biji_manager_notify_changed (self, group,
+                               BIJI_MANAGER_ITEM_DELETED, item);
+}
+
+
+/* Signal if item is known */
+static void
+on_item_trashed_cb (BijiItem *item, BijiManager *self)
+{
+  const gchar *path;
+
+  path = biji_item_get_uuid (item);
+  item = g_hash_table_lookup (self->priv->items, path);
+
+  if (item == NULL)
+    return;
+
+  biji_manager_notify_changed (self, BIJI_LIVING_ITEMS, BIJI_MANAGER_ITEM_TRASHED, item);
+  g_hash_table_insert (self->priv->archives,
+                       (gpointer) biji_item_get_uuid (item), item);
+  g_hash_table_remove (self->priv->items, path);
 }
 
 
@@ -408,6 +439,8 @@ biji_manager_add_item (BijiManager *manager,
     /* Connect */
     g_signal_connect (item, "deleted",
                       G_CALLBACK (on_item_deleted_cb), manager);
+    g_signal_connect (item, "trashed",
+                      G_CALLBACK (on_item_trashed_cb), manager);
     g_signal_connect (item, "restored",
                       G_CALLBACK (on_item_restored_cb), manager);
 
@@ -493,11 +526,24 @@ _add_provider (BijiManager *self,
 
   info = biji_provider_get_info (provider);
   g_hash_table_insert (self->priv->providers, (gpointer) info->unique_id, provider);
-  g_signal_connect (provider, "loaded", 
+  g_signal_connect (provider, "loaded",
                     G_CALLBACK (on_provider_loaded_cb), self);
 }
 
 
+
+
+void
+biji_manager_add_e_source_extension_memo (BijiManager *self,
+                                          ESource *source)
+{
+  BijiProvider *provider = NULL;
+
+  provider = biji_memo_provider_new (self, source);
+  _add_provider (self, provider);
+}
+
+
 void
 biji_manager_add_goa_object (BijiManager *self,
                                GoaObject *object)
@@ -621,36 +667,6 @@ biji_manager_get_default_color (BijiManager *manager, GdkRGBA *color)
 }
 
 
-gboolean
-biji_manager_remove_item (BijiManager *manager, BijiItem *item)
-{
-  g_return_val_if_fail (BIJI_IS_MANAGER (manager), FALSE);
-  g_return_val_if_fail (BIJI_IS_ITEM      (item), FALSE);
-
-  BijiItem *to_delete = NULL;
-  const gchar *path;
-  gboolean retval = FALSE;
-
-  path = biji_item_get_uuid (item);
-  to_delete = g_hash_table_lookup (manager->priv->items, path);
-
-  if (to_delete)
-  {
-    /* Signal before doing anything here. So the note is still
-     * fully available for signal receiver. */
-    biji_manager_notify_changed (manager, BIJI_LIVING_ITEMS, BIJI_MANAGER_ITEM_TRASHED, to_delete);
-    biji_item_trash (item);
-    g_hash_table_insert (manager->priv->archives,
-                         (gpointer) biji_item_get_uuid (item), item);
-    g_hash_table_remove (manager->priv->items, path);
-
-    retval = TRUE;
-  }
-
-  return retval;
-}
-
-
 
 GList *
 biji_manager_get_items             (BijiManager         *manager,
@@ -678,18 +694,6 @@ biji_manager_get_items             (BijiManager         *manager,
 }
 
 
-void
-biji_manager_load_archives          (BijiManager        *manager)
-{
-  GList *l, *ll;
-
-  l = g_hash_table_get_values (manager->priv->providers);
-  for (ll=l; ll!= NULL; ll=ll->next)
-    biji_provider_load_archives (BIJI_PROVIDER (ll->data));
-  g_list_free (l);
-}
-
-
 static void
 _delete_item (gpointer data,
               gpointer user_data)
@@ -741,93 +745,8 @@ biji_manager_new (GFile *location, GdkRGBA *color, GError **error)
 }
 
 
-BijiNoteObj *
-biji_note_get_new_from_file (BijiManager *manager, const gchar* path)
-{
-  BijiInfoSet  set;
-  BijiNoteObj *ret;
-
-  set.url = (gchar*) path;
-  set.mtime = 0;
-  set.title = NULL;
-  set.content = NULL;
-
-  ret = biji_local_note_new_from_info (manager->priv->local_provider, manager, &set);
-  biji_lazy_deserialize (ret);
-
-  return ret ;
-}
-
-gchar *
-biji_manager_get_uuid (void)
-{
-  uuid_t unique;
-  char out[40];
-
-  uuid_generate (unique);
-  uuid_unparse_lower (unique, out);
-  return g_strdup_printf ("%s.note", out);
-}
-
-/* Common UUID skeleton for new notes. */
-static BijiNoteObj *
-get_note_skeleton (BijiManager *manager)
-{
-  BijiNoteObj *ret = NULL;
-  gchar * folder, *name, *path;
-  BijiInfoSet set;
-
-  set.title = NULL;
-  set.content = NULL;
-  set.mtime = 0;
-  folder = g_file_get_path (manager->priv->location);
-
-  while (!ret)
-  {
-    name = biji_manager_get_uuid ();
-    path = g_build_filename (folder, name, NULL);
-    g_free (name);
-    set.url = path;
-
-    if (!g_hash_table_lookup (manager->priv->items, path))
-      ret = biji_local_note_new_from_info (manager->priv->local_provider, manager, &set);
-
-    g_free (path);
-  }
-
-  biji_note_obj_set_all_dates_now (ret);
-  return ret;
-}
 
 
-/* 
- * TODO : move this to local provider.
- */
-static BijiNoteObj *
-biji_manager_local_note_new           (BijiManager *manager, gchar *str)
-{
-  BijiNoteObj *ret = get_note_skeleton (manager);
-
-  if (str)
-  {
-    gchar *unique, *html;
-
-    unique = biji_manager_get_unique_title (manager, str);
-    html = html_from_plain_text (str);
-
-    biji_note_obj_set_title (ret, unique);
-    biji_note_obj_set_raw_text (ret, str);
-    biji_note_obj_set_html (ret, html);
-
-    g_free (unique);
-    g_free (html);
-  }
-
-  biji_note_obj_save_note (ret);
-  biji_manager_add_item (manager, BIJI_ITEM (ret), BIJI_LIVING_ITEMS, TRUE);
-
-  return ret;
-}
 
 
 /* Create the importer == switch depending on the uri.
@@ -852,29 +771,24 @@ biji_manager_import_uri (BijiManager *manager,
  * Use goa_account_get_id for goa
  */
 BijiNoteObj *
-biji_manager_note_new            (BijiManager *manager,
-                                    gchar        *str,
-                                    gchar        *provider_id)
+biji_manager_note_new            (BijiManager  *self,
+                                  gchar        *str,
+                                  gchar        *provider_id)
 {
-  BijiProvider *provider;
+  BijiProvider *provider = NULL;
   BijiNoteObj *retval;
 
-  // If we move local_note_new to create_note for local provider
-  // we won't need this stupid switch.
 
-  if (provider_id == NULL ||
-      g_strcmp0 (provider_id, "local") == 0)
-    return biji_manager_local_note_new (manager, str);
+  if (provider_id != NULL)
+    provider = g_hash_table_lookup (self->priv->providers,
+                                    provider_id);
 
-
-  provider = g_hash_table_lookup (manager->priv->providers,
-                                  provider_id);
+  if (provider == NULL)
+    provider = self->priv->local_provider;
 
 
   retval = BIJI_PROVIDER_GET_CLASS (provider)->create_new_note (provider, str);
-  // do not save. up to the provider implementation to save it or not
-  // at creation.
-  biji_manager_add_item (manager, BIJI_ITEM (retval), BIJI_LIVING_ITEMS, TRUE);
+  biji_manager_add_item (self, BIJI_ITEM (retval), BIJI_LIVING_ITEMS, TRUE);
 
   return retval;
 }
