@@ -274,7 +274,7 @@ on_content_changed (WebKitWebView *view)
   {
     gchar *title;
     gchar *unique_title;
-  
+
     title = rows[0];
 
     if (g_strcmp0 (title, biji_item_get_title (BIJI_ITEM (note))) != 0)
@@ -350,9 +350,10 @@ biji_webkit_editor_constructed (GObject *obj)
   body = biji_note_obj_get_html (priv->note);
 
   if (!body)
-    body = "<html xmlns=\"http://www.w3.org/1999/xhtml\"><body></body></html>";
+    body = html_from_plain_text ("");
 
   webkit_web_view_load_string (view, body, "application/xhtml+xml", NULL, NULL);
+  g_free (body);
 
 
   /* Do not be a browser */
